@@ -6,6 +6,7 @@
 
 import sys
 import os
+import shutil
 
 # Get the location of easy-install.pth
 temp_path = sys.path
@@ -37,3 +38,14 @@ f = open(easy_install_path, 'a')
 f.write(remix_source_string)
 f.write(pyechonest_source_string)
 f.close()
+
+# Copy youtube-dl out
+print "Copying youtube-dl to /usr/local/bin"
+# If we're in a virtualenv:
+if 'real_prefix' in dir(sys):
+    data_path = os.path.join(sys.prefix, "local/bin/youtube-dl")
+else:
+    data_path = '/usr/local/bin/youtube-dl'
+shutil.copyfile('external/youtube-dl/youtube-dl', data_path)
+os.chmod(data_path, 0755)
+
