@@ -747,9 +747,12 @@ def getpieces(audioData, segs):
     :param segs: an iterable containing objects that may be accessed
         as slices or indices for an `AudioData`
     """
-    #calculate length of new segment
-    audioData.data = None
-    audioData.load()
+
+    # Ensure that we have data
+    if audioData.data == None or audioData.defer:
+        audioData.data = None
+        audioData.load()
+
     dur = 0
     for s in segs:
         dur += int(s.duration * audioData.sampleRate)
